@@ -648,6 +648,9 @@ class _SpacelikeGeodesicSolver:
         if difference > np.pi:
             emission_event[3] = emission_event[3] + 2 * np.pi
 
+        if difference < - np.pi:
+            reception_event[3] = reception_event[3] + 2 * np.pi
+
         self.emission_event = emission_event
         self.reception_event = reception_event
         self.metric_derivatives = metric_derivatives
@@ -1007,6 +1010,8 @@ def light_ray_differential_evolution(
         light_ray_data.y[4:8, i],
     ) / c ** 2) for i in range(len(light_ray_data.t))]
 
+    logger.info('The seed for this computation was %s',
+                solver_setup_config.de_seed)
     logger.info('Emission event #%s', dataframe_row_index)
     logger.info('final initial angles: %s', initial_angles)
     logger.info('minimal_distance: %s',
@@ -1252,6 +1257,9 @@ def eop_solver(
         Receiver curve's coordinates and tangent vector at each event.
     multiprocessing
         Switch multiprocessing on to calculate multiple light rays in parallel.
+        Note that when running the code on Windows or macOS, switch the default
+        start method for multiprocessing from 'spawn' to 'fork' manually before
+        calling the function.
     hypersurface_approximation
         Switch on celestial angle approximation via geodesics between events in
         the hypersurface x0=const.
