@@ -28,8 +28,9 @@ class TestGravitationalPotential(TestCase):
 
         potential_analytical = - gravity_constant / r * (
             multipole_moments[0]
-            + (multipole_moments[1] * radius_reference / r
-               * sympy.sin(theta))
+            + multipole_moments[1] * radius_reference / r * sympy.cos(theta)
+            + multipole_moments[2] * (radius_reference / r) ** 2 * (
+                1 / 2 * (3 * sympy.cos(theta) ** 2 - 1 ))                
         )
 
         potential_difference = simplify(potential_from_func
